@@ -20,7 +20,7 @@
 #define __MISC_H__
 
 
-#include <gtk/gtk.h>
+#include "common.h"
 
 
 #define misc_iskanji(ch) (((ch)&0x80)!=0)
