@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <string.h>
 #include "charset.h"
 
 
@@ -627,9 +626,9 @@ void charset_init(void)
 
 	/* Ķѿ */
 	for (i=0;list[i]!=NULL;i++)
-		if ((env=g_getenv(list[i]))!=NULL && (env=strchr(env,'.'))!=NULL) {
+		if ((env=g_getenv(list[i]))!=NULL && (env=g_strchr(env,'.'))!=NULL) {
 			lang=g_strdup(env+1);
-			if ((env=strchr(lang,'@'))!=NULL)
+			if ((env=g_strchr(lang,'@'))!=NULL)
 				*env='\0';
 			charset_set(lang);
 			g_free(lang);
