@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <string.h>
 #include "abort.h"
 #include "command.h"
 #include "edit.h"
@@ -271,7 +270,7 @@ void command_property(gpointer callback_data,guint callback_action,
 	ft.uline=tmaid->uline;
 	ft.vline=tmaid->vline;
 	ft.font_name=g_strdup(tmaid->font_name);
-	memcpy(ft.color,tmaid->color,sizeof(GdkColor)*12);
+	g_memmove(ft.color,tmaid->color,sizeof(GdkColor)*12);
 	ft.text=ft.ext=NULL;
 	if (property_dialog(&ft)) {
 		if (ft.ft_id<0) {
@@ -298,7 +297,7 @@ void command_property(gpointer callback_data,guint callback_action,
 					ftype[i].vline=ft.vline;
 					g_free(ftype[i].font_name);
 					ftype[i].font_name=g_strdup(ft.font_name);
-					memcpy(ftype[i].color,ft.color,sizeof(GdkColor)*12);
+					g_memmove(ftype[i].color,ft.color,sizeof(GdkColor)*12);
 					break;
 				}
 			glist=gtk_container_children(GTK_CONTAINER(notebook));
@@ -551,20 +550,20 @@ void command_find(gpointer callback_data,guint callback_action,
 		find_arrow=fd.arrow;
 		find_ignorecase=fd.ignorecase;
 		for (i=0;i<find_num;i++)
-			if (strcmp(fd.text,find_text[i])==0)
+			if (g_strcmp(fd.text,find_text[i])==0)
 				break;
 		if (i==find_num) {
 			if (find_num>=32)
 				g_free(find_text[31]);
 			else
 				find_num++;
-			memmove(find_text+1,find_text,(find_num-1)*sizeof(gchar *));
+			g_memmove(find_text+1,find_text,(find_num-1)*sizeof(gchar *));
 			find_text[0]=fd.text;
 		} else {
 			g_free(fd.text);
 			if (i>0) {
 				text=find_text[i];
-				memmove(find_text+1,find_text,i*sizeof(gchar *));
+				g_memmove(find_text+1,find_text,i*sizeof(gchar *));
 				find_text[0]=text;
 			}
 		}
@@ -625,37 +624,37 @@ void command_replace(gpointer callback_data,guint callback_action,
 		replace_arrow=rp.arrow;
 		replace_ignorecase=rp.ignorecase;
 		for (i=0;i<find_num;i++)
-			if (strcmp(rp.src,find_text[i])==0)
+			if (g_strcmp(rp.src,find_text[i])==0)
 				break;
 		if (i==find_num) {
 			if (find_num>=32)
 				g_free(find_text[31]);
 			else
 				find_num++;
-			memmove(find_text+1,find_text,(find_num-1)*sizeof(gchar *));
+			g_memmove(find_text+1,find_text,(find_num-1)*sizeof(gchar *));
 			find_text[0]=rp.src;
 		} else {
 			g_free(rp.src);
 			text=find_text[i];
-			memmove(find_text+1,find_text,i*sizeof(gchar *));
+			g_memmove(find_text+1,find_text,i*sizeof(gchar *));
 			find_text[0]=text;
 		}
 		if (rp.dst[0]!='\0') {
 			for (i=0;i<replace_num;i++)
-				if (strcmp(rp.dst,replace_text[i])==0)
+				if (g_strcmp(rp.dst,replace_text[i])==0)
 						break;
 			if (i==replace_num) {
 				if (replace_num>=32)
 					g_free(replace_text[31]);
 				else
 					replace_num++;
-				memmove(replace_text+1,replace_text,
+				g_memmove(replace_text+1,replace_text,
 											(replace_num-1)*sizeof(gchar *));
 				replace_text[0]=rp.dst;
 			} else {
 				g_free(rp.dst);
 				text=replace_text[i];
-				memmove(replace_text+1,replace_text,i*sizeof(gchar *));
+				g_memmove(replace_text+1,replace_text,i*sizeof(gchar *));
 				replace_text[0]=text;
 			}
 		}
@@ -685,11 +684,11 @@ void command_replace(gpointer callback_data,guint callback_action,
 				data_pos=edit_get_data_pos(tmaid,select.x,select.y,FALSE);
 			else
 				data_pos=-1;
-			d=edit_operation(tmaid,replace_text[0],strlen(replace_text[0]),
+			d=edit_operation(tmaid,replace_text[0],g_strlen(replace_text[0]),
 														replace_arrow,TRUE);
 			if (data_pos>=0)
 				select.x=edit_get_screen_pos(tmaid,
-									data_pos+strlen(rp.dst)-bytes,select.y);
+									data_pos+g_strlen(rp.dst)-bytes,select.y);
 			if (result==REPLACE_OK || result==REPLACE_ALL)
 				count++;
 			d->next=tmaid->undo;
