@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <string.h>
 #include "charset.h"
 #include "edit.h"
 #include "misc/misc.h"
@@ -373,25 +372,25 @@ void edit_cpy_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p,
 	p=edit_get_line_buf(&tmaid->start,&tmaid->off,st.y);
 	if (st.y==ed.y) {
 		/* Ʊ */
-		memcpy(text,p->text+st_pos,(ed_pos-st_pos)*sizeof(gchar));
+		g_memmove(text,p->text+st_pos,(ed_pos-st_pos)*sizeof(gchar));
 	} else {
 		/* 㤦 */
 		length=p->length-st_pos;
-		memcpy(text,p->text+st_pos,length*sizeof(gchar));
+		g_memmove(text,p->text+st_pos,length*sizeof(gchar));
 		if (!p->margin) {
-			memcpy(text+length,"\n",sizeof(gchar));
+			g_memmove(text+length,"\n",sizeof(gchar));
 			length++;
 		}
 		for (i=st.y+1,p=p->next;i<ed.y && p!=NULL;i++,p=p->next) {
-			memcpy(text+length,p->text,p->length*sizeof(gchar));
+			g_memmove(text+length,p->text,p->length*sizeof(gchar));
 			length+=p->length;
 			if (!p->margin) {
 				/*  */
-				memcpy(text+length,"\n",sizeof(gchar));
+				g_memmove(text+length,"\n",sizeof(gchar));
 				length++;
 			}
 		}
-		memcpy(text+length,p->text,ed_pos*sizeof(gchar));
+		g_memmove(text+length,p->text,ed_pos*sizeof(gchar));
 	}
 }
 
@@ -413,7 +412,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 	data_pos=edit_get_data_pos(tmaid,put->x,put->y,FALSE);
 	p=edit_get_line_buf(&tmaid->start,&tmaid->off,put->y);
 	if (data_pos<=0 && p->prev!=NULL && p->prev->margin && length>=1
-									&& memcmp(text,"\n",sizeof(gchar))==0) {
+									&& g_memcmp(text,"\n",sizeof(gchar))==0) {
 		/* ƬؤιԤޤ֤ƤꡢʸԤΤȤ */
 		p=p->prev;
 		data_pos=p->length;
@@ -424,7 +423,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 		/* ְʹߤʸХåե¸ */
 		temp_leng=p->length-data_pos;
 		temp=g_malloc(temp_leng*sizeof(gchar));
-		memcpy(temp,p->text+data_pos,temp_leng*sizeof(gchar));
+		g_memmove(temp,p->text+data_pos,temp_leng*sizeof(gchar));
 		p->length=data_pos;
 	} else {
 		temp_leng=0;
@@ -464,7 +463,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 			if (p->length>0 || i!=data_pos)
 				p->text=g_realloc(p->text,
 										(p->length+data_pos-i)*sizeof(gchar));
-			memcpy(p->text+p->length,text+i,(data_pos-i)*sizeof(gchar));
+			g_memmove(p->text+p->length,text+i,(data_pos-i)*sizeof(gchar));
 			p->length+=data_pos-i;
 			if (length<=data_pos) {
 				i=data_pos;
@@ -500,7 +499,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 			if (p->length>0 || i!=data_pos)
 				p->text=g_realloc(p->text,
 										(p->length+data_pos-i)*sizeof(gchar));
-			memcpy(p->text+p->length,text+i,(data_pos-i)*sizeof(gchar));
+			g_memmove(p->text+p->length,text+i,(data_pos-i)*sizeof(gchar));
 			p->length+=data_pos-i;
 			if (length<=data_pos) {
 				i=data_pos;
@@ -546,7 +545,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 	if (temp!=NULL) {
 		/* ְʹߤʸ᤹ */
 		p->text=g_realloc(p->text,(p->length+temp_leng)*sizeof(gchar));
-		memcpy(p->text+p->length,temp,temp_leng*sizeof(gchar));
+		g_memmove(p->text+p->length,temp,temp_leng*sizeof(gchar));
 		p->length+=temp_leng;
 		g_free(temp);
 	}
@@ -583,7 +582,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 				p->next=q;
 				if (q->next!=NULL)
 					q->next->prev=q;
-				memcpy(q->text,p->text+data_pos,q->length*sizeof(gchar));
+				g_memmove(q->text,p->text+data_pos,q->length*sizeof(gchar));
 				p->length=data_pos;
 				p->margin=TRUE;
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
@@ -600,7 +599,7 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 				p->length+=q->length;
 				p->margin=q->margin;
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
-				memcpy(p->text+data_pos,q->text,q->length*sizeof(gchar));
+				g_memmove(p->text+data_pos,q->text,q->length*sizeof(gchar));
 				g_free(q->text);
 				g_free(q);
 				insert--;
@@ -635,7 +634,8 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 	p=edit_get_line_buf(&tmaid->start,&tmaid->off,st.y);
 	if (st.y==ed.y) {
 		/* Ʊ */
-		memcpy(p->text+st_pos,p->text+ed_pos,(p->length-ed_pos)*sizeof(gchar));
+		g_memmove(p->text+st_pos,p->text+ed_pos,
+											(p->length-ed_pos)*sizeof(gchar));
 		p->length-=ed_pos-st_pos;
 		p->text=g_realloc(p->text,p->length);
 		result=0;
@@ -652,7 +652,8 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 		p->length=st_pos+q->length-ed_pos;
 		p->margin=q->margin;
 		p->text=g_realloc(p->text,p->length);
-		memcpy(p->text+st_pos,q->text+ed_pos,(q->length-ed_pos)*sizeof(gchar));
+		g_memmove(p->text+st_pos,q->text+ed_pos,
+											(q->length-ed_pos)*sizeof(gchar));
 		g_free(q->text);
 		g_free(q);
 		result=ed.y-st.y;
@@ -694,7 +695,7 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 			q->length+=p->length;
 			q->margin=p->margin;
 			q->text=g_realloc(q->text,q->length*sizeof(gchar));
-			memcpy(q->text+data_pos,p->text,p->length*sizeof(gchar));
+			g_memmove(q->text+data_pos,p->text,p->length*sizeof(gchar));
 			g_free(p->text);
 			g_free(p);
 			result++;
@@ -742,7 +743,7 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 				p->next=q;
 				if (q->next!=NULL)
 					q->next->prev=q;
-				memcpy(q->text,p->text+data_pos,q->length*sizeof(gchar));
+				g_memmove(q->text,p->text+data_pos,q->length*sizeof(gchar));
 				p->length=data_pos;
 				p->margin=TRUE;
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
@@ -759,7 +760,7 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 				p->length+=q->length;
 				p->margin=q->margin;
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
-				memcpy(p->text+data_pos,q->text,q->length*sizeof(gchar));
+				g_memmove(p->text+data_pos,q->text,q->length*sizeof(gchar));
 				g_free(q->text);
 				g_free(q);
 				result++;
