@@ -16,8 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <ctype.h>
-#include <string.h>
 #include "charset.h"
 #include "command.h"
 #include "edit.h"
@@ -483,7 +481,7 @@ void modify_margin(TmaidWindow *tmaid)
 				p->next=q;
 				if (q->next!=NULL)
 					q->next->prev=q;
-				memcpy(q->text,p->text+data_pos,q->length*sizeof(gchar));
+				g_memmove(q->text,p->text+data_pos,q->length*sizeof(gchar));
 				p->length=data_pos;
 				p->margin=TRUE;
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
@@ -500,7 +498,7 @@ void modify_margin(TmaidWindow *tmaid)
 				p->length+=q->length;
 				p->margin=q->margin;
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
-				memcpy(p->text+data_pos,q->text,q->length*sizeof(gchar));
+				g_memmove(p->text+data_pos,q->text,q->length*sizeof(gchar));
 				g_free(q->text);
 				g_free(q);
 				tmaid->max--;
@@ -521,7 +519,7 @@ void modify_margin(TmaidWindow *tmaid)
 				p->length+=q->length;
 				p->margin=q->margin;
 				p->text=g_realloc(p->text,p->length*sizeof(gchar));
-				memcpy(p->text+data_pos,q->text,q->length*sizeof(gchar));
+				g_memmove(p->text+data_pos,q->text,q->length*sizeof(gchar));
 				g_free(q->text);
 				g_free(q);
 				tmaid->max--;
@@ -658,7 +656,7 @@ void tab_operation(TmaidWindow *tmaid)
 			}
 		if (screen_pos>data_pos) {
 			temp=g_malloc(screen_pos*sizeof(gchar));
-			memset(temp,' ',screen_pos*sizeof(gchar));
+			g_memset(temp,' ',screen_pos*sizeof(gchar));
 			data_pos=screen_pos=0;
 			while (data_pos<p->length)
 				if (p->text[data_pos]=='\t') {
@@ -666,7 +664,7 @@ void tab_operation(TmaidWindow *tmaid)
 					data_pos++;
 				} else if (data_pos+charset_length(p->text[data_pos])
 																<=p->length) {
-					memmove(temp+screen_pos,p->text+data_pos,
+					g_memmove(temp+screen_pos,p->text+data_pos,
 											charset_length(p->text[data_pos]));
 					screen_pos+=charset_width(tmaid->font,
 										p->text+data_pos,tmaid->font_width);
