@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,77 +24,72 @@
 
 
 /*	åȤ
-	   ptw,TXTɥ
+	 tmaid,TXTɥ
 	cursor,												*/
-void draw_caret(TEXTWND *ptw,GdkPoint *cursor);
+void draw_caret(TmaidWindow *tmaid,GdkPoint *cursor);
 
 
 /*	˥塼ꤹ
-	ptw,TXTɥ													*/
-void set_menu_bar(TEXTWND *ptw);
+	tmaid,TXTɥ													*/
+void set_menu_bar(TmaidWindow *tmaid);
 
 
 /*	ϰϤ褹
-	ptw,TXTɥ
+	tmaid,TXTɥ
 	start,
 	  end,λ																*/
-void clear_sel(TEXTWND *ptw,GdkPoint *start,GdkPoint *end);
+void clear_sel(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end);
 
 
 /*	ư
-	ptw,TXTɥ
-	top,Ťκɸ														*/
-void move_edit_window(TEXTWND *ptw,GdkPoint *top);
+	tmaid,TXTɥ
+	  top,Ťκɸ													*/
+void move_edit_window(TmaidWindow *tmaid,GdkPoint *top);
 
 
 /*	åȰ֤˥ǡ/񤭤
-	   ptw,TXTɥ
+	 tmaid,TXTɥ
 	  text,ǡǼݥ
 	length,ǡΥХȿ
 	 caret,TRUE:ư,FALSE:ưʤ
 	select,TRUE:򤹤,FALSE:򤷤ʤ
-	   RET,դԤDOING¤,NULL:顼							*/
-DOING *edit_operation(TEXTWND *ptw,gchar *text,gint length,
-											gboolean caret,gboolean select);
+	   RET,դԤTmaidHistory¤,NULL:顼						*/
+TmaidHistory *edit_operation(TmaidWindow *tmaid,
+								const gchar *text,const gint length,
+								const gboolean caret,const gboolean select);
 
 
 /*	ꥹȤ
 	  d,ꥹȤƬ
 	RET,ꥹȤο													*/
-gint delete_list(DOING **d);
+gint delete_list(TmaidHistory **d);
 
 
 /*	ޡޤ֤
-	ptw,TXTɥ													*/
-void modify_margin(TEXTWND *ptw);
-
-
-/*	ץѥƥѹ
-	ptw,TXTɥ
-	 ft,ե륿														*/
-void change_property(TEXTWND *ptw,FTYPE *ft);
+	tmaid,TXTɥ													*/
+void modify_margin(TmaidWindow *tmaid);
 
 
 /*	ե¸䤤碌
-	ptw,TXTɥ
-	RET,TRUE:եĤ,FALSE:եĤʤ						*/
-gboolean prompt_close(TEXTWND *ptw);
+	tmaid,TXTɥ
+	  RET,TRUE:եĤ,FALSE:եĤʤ					*/
+gboolean prompt_close(TmaidWindow *tmaid);
 
 
 /*	Խ
-	 ptw,TXTɥ
-	kind,TRUE:redo,FALSE:undo												*/
-void history_operation(TEXTWND *ptw,gboolean kind);
+	tmaid,TXTɥ
+	 kind,TRUE:redo,FALSE:undo												*/
+void history_operation(TmaidWindow *tmaid,const gboolean kind);
 
 
 /*	ޡǲԤ
-	 ptw,TXTɥ													*/
-void margin_operation(TEXTWND *ptw);
+	tmaid,TXTɥ													*/
+void margin_operation(TmaidWindow *tmaid);
 
 
 /*	֤򥹥ڡѴ
-	 ptw,TXTɥ													*/
-void tab_operation(TEXTWND *ptw);
+	tmaid,TXTɥ													*/
+void tab_operation(TmaidWindow *tmaid);
 
 
 #endif
