@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,19 +24,19 @@
 #ifdef USE_GDKPIXBUF
 
 
-typedef struct prncfg {
+typedef struct PrintConfig_Tag {
 	gboolean mode,select;
 	gchar *printer,*file;
 	gint width,height,left,top,right,bottom;
-	gint column,fontwidth,fontheight;
-} PRNCFG;
+	gint column,font_width,font_height;
+} PrintConfig;
 
 
-extern PRNCFG printer;					/* ̐ݒ */
+extern PrintConfig printer;				/* ̐ݒ */
 
 
-gboolean print_out(TEXTWND *ptw,PRNCFG *prncfg);
-gboolean print_dialog(PRNCFG *prncfg);
+gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg);
+gboolean print_dialog(PrintConfig *prncfg);
 
 
 #endif
