@@ -17,7 +17,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <gdk/gdkkeysyms.h>
-#include <string.h>
 #include "charset.h"
 #include "edit.h"
 #include "ftype.h"
@@ -48,7 +47,7 @@ void property_change(TmaidWindow *tmaid,FileType *ft)
 	}
 	modify=tmaid->limit!=ft->limit || (tmaid->limit
 						&& (tmaid->tab!=ft->tab || tmaid->margin!=ft->margin
-								|| strcmp(tmaid->font_name,ft->font_name)!=0));
+							|| g_strcmp(tmaid->font_name,ft->font_name)!=0));
 	tmaid->ft_id=ft->ft_id;
 	tmaid->margin=ft->margin;
 	tmaid->tab=ft->tab;
@@ -66,7 +65,7 @@ void property_change(TmaidWindow *tmaid,FileType *ft)
 	tmaid->vline=ft->vline;
 	g_free(tmaid->font_name);
 	tmaid->font_name=g_strdup(ft->font_name);
-	memcpy(tmaid->color,ft->color,sizeof(GdkColor)*12);
+	g_memmove(tmaid->color,ft->color,sizeof(GdkColor)*12);
 	tmaid->select.x=-1;
 	/* ե */
 	if (tmaid->font_name!=NULL) {
@@ -139,8 +138,9 @@ static gchar *color_name[12]={
 static void property_dialog_ok_sensitive(GtkWidget *widget,gpointer user_data)
 {
 	gtk_widget_set_sensitive(button3,
-		(entry0==NULL || strlen(gtk_entry_get_text(GTK_ENTRY(entry0)))>0)
-		&& (entry1==NULL || strlen(gtk_entry_get_text(GTK_ENTRY(entry1)))>0));
+		(entry0==NULL || g_strlen(gtk_entry_get_text(GTK_ENTRY(entry0)))>0)
+		&& (entry1==NULL
+						|| g_strlen(gtk_entry_get_text(GTK_ENTRY(entry1)))>0));
 }
 
 
@@ -318,7 +318,7 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),
 														ftype[pos].margin);
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),ftype[pos].tab);
-			memcpy(gdk_color,ftype[pos].color,sizeof(GdkColor)*12);
+			g_memmove(gdk_color,ftype[pos].color,sizeof(GdkColor)*12);
 			g_free(font_name);
 			font_name=g_strdup(ftype[pos].font_name);
 			gtk_widget_set_sensitive(button3,TRUE);
@@ -359,7 +359,7 @@ static void property_dialog_clicked_ok(GtkWidget *widget,FileType *ft)
 	ft->syscol=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check11));
 	if (check12!=NULL)
 		ft->associate=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check12));
-	memcpy(ft->color,gdk_color,sizeof(GdkColor)*12);
+	g_memmove(ft->color,gdk_color,sizeof(GdkColor)*12);
 	g_free(ft->font_name);
 	ft->font_name=font_name;
 	font_name=NULL;
@@ -371,8 +371,8 @@ static void property_dialog_clicked_ok(GtkWidget *widget,FileType *ft)
 /* ԥܥǥ꥿󤬲줿 */
 static void property_dialog_activate(GtkWidget *widget,FileType *ft)
 {
-	if ((entry0==NULL || strlen(gtk_entry_get_text(GTK_ENTRY(entry0)))>0)
-		&& (entry1==NULL || strlen(gtk_entry_get_text(GTK_ENTRY(entry1)))>0))
+	if ((entry0==NULL || g_strlen(gtk_entry_get_text(GTK_ENTRY(entry0)))>0)
+		&& (entry1==NULL || g_strlen(gtk_entry_get_text(GTK_ENTRY(entry1)))>0))
 		property_dialog_clicked_ok(widget,ft);
 }
 
@@ -710,7 +710,7 @@ gboolean property_dialog(FileType *ft)
 	gtk_widget_grab_focus(button4);
 
 	ft_id=ft->ft_id;
-	memcpy(gdk_color,ft->color,sizeof(GdkColor)*12);
+	g_memmove(gdk_color,ft->color,sizeof(GdkColor)*12);
 	font_name=g_strdup(ft->font_name);
 	property_clicked_ok=FALSE;
 
