@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,13 @@
 #include "tmaid.h"
 
 
-gboolean property_dialog(FTYPE *ft);
+/*	vpeBύX
+	tmaid,TXTEChE
+	   ft,t@C^Cv													*/
+void property_change(TmaidWindow *tmaid,FileType *ft);
+
+
+gboolean property_dialog(FileType *ft);
 
 
 #endif
