@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <string.h>
 #include <gdk/gdkkeysyms.h>
 #include "argument.h"
 #include "charset.h"
@@ -360,7 +359,7 @@ gboolean signal_expose(GtkWidget *widget,
 					for (i=0;charset->space[i]!=0;i+=charset->space[i]+1)
 						if (charset_length(p->text[data_pos])
 															==charset->space[i]
-								&& memcmp(p->text+data_pos,charset->space+i+1,
+							&& g_memcmp(p->text+data_pos,charset->space+i+1,
 														charset->space[i])==0)
 							space=TRUE;
 				}
@@ -546,7 +545,7 @@ gboolean signal_button_press(GtkWidget *widget,
 				draw_caret(tmaid,&cursor);
 				if (text!=NULL) {
 					/* Žդ */
-					d=edit_operation(tmaid,text,strlen(text),FALSE,TRUE);
+					d=edit_operation(tmaid,text,g_strlen(text),FALSE,TRUE);
 					d->next=tmaid->undo;
 					tmaid->undo=d;
 					if (delete_list(&tmaid->redo)>0 || d->next==NULL
@@ -1109,7 +1108,7 @@ gboolean signal_key_press(GtkWidget *widget,
 						break;
 				text=g_malloc((i+1)*sizeof(gchar));
 				text[0]='\n';
-				memcpy(text+1,p->text,i*sizeof(gchar));
+				g_memmove(text+1,p->text,i*sizeof(gchar));
 				d=edit_operation(tmaid,text,i+1,TRUE,FALSE);
 				g_free(text);
 			} else {
@@ -1540,7 +1539,7 @@ void signal_drag_data_received(GtkWidget *widget,GdkDragContext *context,
 
 	files=g_strsplit(selection_data->data,"\r\n",G_MAXINT);
 	for (i=0;files[i]!=NULL;i++)
-		if (strncmp(files[i],"file:",5)==0)
+		if (g_strncmp(files[i],"file:",5)==0)
 			file_open_edit(files[i]+5);
 	g_strfreev(files);
 }
@@ -1578,19 +1577,19 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 		/* åץܡ */
 		if (clipboard_text!=NULL) {
 			text=clipboard_text;
-			length=strlen(clipboard_text);
+			length=g_strlen(clipboard_text);
 		}
 	} else if (data->selection==atom_textmaid0) {
 		/* ץ̿ */
 		text="Text maid Selection";
-		length=strlen(text);
+		length=g_strlen(text);
 		gtk_selection_convert(window,atom_textmaid1,
 								GDK_SELECTION_TYPE_STRING,GDK_CURRENT_TIME);
 	} else if (data->selection==atom_textmaid1 && arg_text!=NULL) {
 		/* ץ̿ */
 		text=arg_text;
 		arg_text=NULL;
-		length=strlen(text);
+		length=g_strlen(text);
 	}
 	if (text!=NULL) {
 		if (info==TARGET_STRING) {
@@ -1659,7 +1658,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 					gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
 			select=tmaid->select;
-			d=edit_operation(tmaid,text,strlen(text),
+			d=edit_operation(tmaid,text,g_strlen(text),
 										data->selection==atom_clipboard,FALSE);
 			d->next=tmaid->undo;
 			tmaid->undo=d;
