@@ -17,7 +17,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <locale.h>
-#include <string.h>
 #include <unistd.h>
 #include "tmaid.h"
 #include "argument.h"
@@ -170,7 +169,7 @@ int main(int argc,char *argv[])
 
 	def_width=gdk_screen_width()*2/3;
 	def_height=gdk_screen_height()*2/3;
-	memset(history_files,0,sizeof(gchar *)*10);
+	g_memset(history_files,0,sizeof(gchar *)*10);
 	/* 쥸ȥ꤫ɤ߽Ф */
 	if ((profile=profile_open(".tmaid"))!=NULL) {
 		if (!profile_get_value(profile,"tmaid","ftnum",
@@ -364,7 +363,7 @@ int main(int argc,char *argv[])
 			if (!profile_get_value(profile,section,"color",
 								(gpointer)&ftype[i].color,sizeof(GdkColor)*12,
 													PROFILE_VALUE_TYPE_ARRAY))
-				memcpy(ftype[i].color,system_color,sizeof(GdkColor)*12);
+				g_memmove(ftype[i].color,system_color,sizeof(GdkColor)*12);
 			g_free(section);
 		}
 		profile_close(profile);
@@ -406,7 +405,7 @@ int main(int argc,char *argv[])
 		/* ե */
 		ftype[0].font_name=NULL;
 		/*  */
-		memcpy(ftype[0].color,system_color,sizeof(GdkColor)*12);
+		g_memmove(ftype[0].color,system_color,sizeof(GdkColor)*12);
 	}
 
 	/* ᥤ󥦥ɥ */
@@ -527,14 +526,14 @@ int main(int argc,char *argv[])
 		for (i=1;i<argc;i++) {
 			if (arg_files[i-1]) {
 				arg=misc_get_full_path(argv[i]);
-				leng=strlen(arg)*sizeof(gchar);
+				leng=g_strlen(arg)*sizeof(gchar);
 				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
-				memcpy(arg_text+length,arg,leng);
+				g_memmove(arg_text+length,arg,leng);
 				g_free(arg);
 			} else {
-				leng=strlen(argv[i])*sizeof(gchar);
+				leng=g_strlen(argv[i])*sizeof(gchar);
 				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
-				memcpy(arg_text+length,argv[i],leng);
+				g_memmove(arg_text+length,argv[i],leng);
 			}
 			length+=leng;
 			arg_text[length++]='\n';
@@ -612,17 +611,17 @@ int main(int argc,char *argv[])
 						(gpointer)&n_pos,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		if (open_path!=NULL)
 			profile_set_value(profile,"tmaid","openpath",(gpointer)open_path,
-										(strlen(open_path)+1)*sizeof(gchar),
+										(g_strlen(open_path)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 		if (save_path!=NULL)
 			profile_set_value(profile,"tmaid","savepath",(gpointer)save_path,
-										(strlen(save_path)+1)*sizeof(gchar),
+										(g_strlen(save_path)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 		/* ե */
 		for (i=0;i<history && history_files[i]!=NULL;i++) {
 			key=g_strdup_printf("history%d",i);
 			profile_set_value(profile,"tmaid",key,(gpointer)history_files[i],
-									(strlen(history_files[i])+1)*sizeof(gchar),
+								(g_strlen(history_files[i])+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			g_free(key);
 		}
@@ -644,7 +643,7 @@ int main(int argc,char *argv[])
 		for (i=0;i<find_num;i++) {
 			key=g_strdup_printf("find%02d",i);
 			profile_set_value(profile,"tmaid",key,(gpointer)find_text[i],
-										(strlen(find_text[i])+1)*sizeof(gchar),
+									(g_strlen(find_text[i])+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			g_free(key);
 		}
@@ -666,7 +665,7 @@ int main(int argc,char *argv[])
 		for (i=0;i<replace_num;i++) {
 			key=g_strdup_printf("replace%02d",i);
 			profile_set_value(profile,"tmaid",key,(gpointer)replace_text[i],
-									(strlen(replace_text[i])+1)*sizeof(gchar),
+								(g_strlen(replace_text[i])+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			g_free(key);
 		}
@@ -682,11 +681,11 @@ int main(int argc,char *argv[])
 									(gpointer)&printer.mode,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"printer","printer",
-									(gpointer)printer.printer,
-									(strlen(printer.printer)+1)*sizeof(gchar),
+								(gpointer)printer.printer,
+								(g_strlen(printer.printer)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 		profile_set_value(profile,"printer","file",(gpointer)printer.file,
-										(strlen(printer.file)+1)*sizeof(gchar),
+									(g_strlen(printer.file)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 		profile_set_value(profile,"printer","width",
 										(gpointer)&printer.width,sizeof(gint),
@@ -712,10 +711,10 @@ int main(int argc,char *argv[])
 		for (i=0;i<ftnum;i++) {
 			section=g_strdup_printf("filetype%04d",i);
 			profile_set_value(profile,section,"text",(gpointer)ftype[i].text,
-									(strlen(ftype[i].text)+1)*sizeof(gchar),
+									(g_strlen(ftype[i].text)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			profile_set_value(profile,section,"ext",(gpointer)ftype[i].ext,
-										(strlen(ftype[i].ext)+1)*sizeof(gchar),
+									(g_strlen(ftype[i].ext)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			profile_set_value(profile,section,"margin",
 									(gpointer)&ftype[i].margin,sizeof(gint),
@@ -766,7 +765,7 @@ int main(int argc,char *argv[])
 			if (ftype[i].font_name!=NULL)
 				profile_set_value(profile,section,"font",
 								(gpointer)ftype[i].font_name,
-								(strlen(ftype[i].font_name)+1)*sizeof(gchar),
+								(g_strlen(ftype[i].font_name)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			/*  */
 			profile_set_value(profile,section,"color",
