@@ -20,12 +20,7 @@
 #define __TMAID_H__
 
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-
-#include <gtk/gtk.h>
+#include "common.h"
 #include "intl.h"
 
 
